@@ -287,8 +287,9 @@ class Actions(object):
             )
         elif IS_MACOS or IS_LINUX:
             print_line(
-                "- {cyan}activate venv command: source {path}".format(
+                "- {cyan}activate venv command: {reset}source {path}".format(
                     cyan=Fore.CYAN,
+                    reset=Style.RESET_ALL,
                     path=colorful_path(config.path_venv_bin_activate),
                 )
             )
@@ -451,11 +452,14 @@ class Actions(object):
             )
         )
         if _dry_run is False:
+            cwd = os.getcwd()
+            os.chdir(config.dir_project_root)
             subprocess.call([
                 config.path_venv_bin_pytest,
                 config.dir_tests,
                 "-s",
             ])
+            os.chdir(cwd)
         pgr_print_done(indent=1)
 
     @subcommand(
@@ -488,14 +492,17 @@ class Actions(object):
             )
         )
         if _dry_run is False:
+            cwd = os.getcwd()
+            os.chdir(config.dir_project_root)
             subprocess.call([
                 config.path_venv_bin_pytest,
                 config.dir_tests,
                 "-s",
                 "--cov={}".format(config.PACKAGE_NAME.get_value()),
                 "--cov-report", "term-missing",
-                "--cov-report", "annotate:{}".format(config.dir_coverage_annotate),
+                "--cov-report", "html:{}".format(config.dir_coverage_html),
             ])
+            os.chdir(cwd)
         pgr_print_done(indent=1)
 
     @subcommand(
@@ -513,6 +520,29 @@ class Actions(object):
             remove_if_exists(config.dir_coverage_annotate)
         self.test_cov_only(config, _dry_run=_dry_run, **kwargs)
 
+    @subcommand(
+        help="** View code coverage test result in web browser.",
+    )
+    def view_cov(self, config, _dry_run=False, **kwargs):
+        """
+        :type config: RepoConfig
+        """
+        pgr_print(
+            "{cyan}Open code coverage test html result in web browser{reset}{cov_html_index}".format(
+                cyan=Fore.CYAN,
+                reset=Style.RESET_ALL,
+                cov_html_index=config.path_coverage_html_index,
+            )
+        )
+
+        if not os.path.exists(config.path_coverage_html_index):
+            raise ValueError("code coverage test results not available yet, you may run 'pgr cov' first!")
+
+        if _dry_run is False:
+            subprocess.call([OPEN_COMMAND, config.path_coverage_html_index])
+
+        pgr_print_done(indent=1)
+
     @subcommand(
         name="tox-only",
         help="Run matrix test in tox with pytest",
@@ -587,6 +617,10 @@ class Actions(object):
             )
         )
         if _dry_run is False:
+            # equivalent to source ./bin/activate
+            os.environ["PATH"] = config.dir_venv_bin + os.pathsep + os.environ.get("PATH", "")
+            os.environ["VIRTUAL_ENV"] = config.dir_venv
+            # call sphinx make html command
             subprocess.call([
                 "make",
                 "-C", config.dir_sphinx_doc,
@@ -651,7 +685,7 @@ class Actions(object):
         ):
             path_doc_index_html = os.path.join(config.dir_sphinx_doc_build_html, "README.html")
         else:
-            raise ValueError
+            raise ValueError("documentation index html file not exists!")
 
         if _dry_run is False:
             subprocess.call([OPEN_COMMAND, path_doc_index_html])
