@@ -283,6 +283,14 @@ class RepoConfig(
     def dir_coverage_annotate(self):
         return os.path.join(self.dir_project_root, ".coverage.annotate")
 
+    @property
+    def dir_coverage_html(self):
+        return os.path.join(self.dir_project_root, "htmlcov")
+
+    @property
+    def path_coverage_html_index(self):
+        return os.path.join(self.dir_coverage_html, "index.html")
+
     @property
     def dir_tox_cache(self):
         return os.path.join(self.dir_project_root, ".tox")
@@ -362,7 +370,7 @@ class RepoConfig(
         if IS_WINDOWS:
             return "/c/Python{}.{}/python.exe".format(self.DEV_PY_VER_MAJOR, self.DEV_PY_VER_MINOR)
         elif IS_MACOS or IS_LINUX:
-            return os.path.join(
+            pyenv_python = os.path.join(
                 self.DIR_HOME.get_value(),
                 ".pyenv",
                 "shims",
@@ -371,6 +379,14 @@ class RepoConfig(
                     self.DEV_PY_VER_MINOR.get_value(),
                 )
             )
+            if os.path.exists(pyenv_python):
+                return pyenv_python
+
+            global_python = "python{}.{}".format(
+                self.DEV_PY_VER_MAJOR.get_value(),
+                self.DEV_PY_VER_MINOR.get_value(),
+            )
+            return global_python
         else:
             raise EnvironmentError
 
@@ -470,7 +486,10 @@ class RepoConfig(
 
     @property
     def path_venv_bin_activate(self):
-        return os.path.join(self.dir_venv_bin, "activate")
+        if IS_WINDOWS:
+            return os.path.join(self.dir_venv_bin, "activate.bat")
+        elif IS_MACOS or IS_LINUX:
+            return os.path.join(self.dir_venv_bin, "activate")
 
     @property
     def path_venv_bin_pytest(self):
